$(function() {
	
	var connection = null;

	$('#log').html('');

	function _log(m) {
		console.log(m);
		$('#log').append(m);
		$('#log').append('<br/>');
	}


	$('#btn-go').click(async function() {		
		var url = $('#url').val(), apikey = $('#apikey').val();

		if (url.length == 0 || apikey.length == 0) { alert("please enter url and api key!"); return; }

		var s = document.title = 'Connecting to ' + url + ' with api key ' + apikey;
		$('#log').html(s + "<br/>");

		if (connection != null && (connection.state === signalR.HubConnectionState.Connected)) {			
			try {
				connection.stopping = true;				
				await connection.stop();
				_log('disconnected from previous host');
			} catch(E) { _log('disconnect error: ' + E); }
		}
		var s = document.title = 'Connecting to ' + url + ' with api key ' + apikey;

		var retryPolicy = {
			nextRetryDelayInMilliseconds: function(context) {
				const retryCount = context.previousRetryCount;
				var retryDelay = 0;
		
				if (retryCount === 0) {
				  retryDelay = Math.floor(Math.random()*4000+1000); // wait 1..5 seconds
				} else if (retryCount < 3) {
				  retryDelay = Math.floor(Math.random()*5000+5000); // wait 5..10 seconds
				} else {
				  retryDelay = Math.floor(Math.random()*30000+30000); // wait 30..60 seconds
				}
		
				_log(`retry policy: connection retry will be started in ${retryDelay / 1000} seconds`);
				return retryDelay;
			  },		
		};

		connection = new signalR.HubConnectionBuilder()
					.withUrl(url + "/rt-api/orderstate", {
						accessTokenFactory: () => 'apikey-' + apikey,   
					})    
					.withAutomaticReconnect(retryPolicy)
					.configureLogging(signalR.LogLevel.Information)
					.build();
		
		connection.on('OrderStateChanged', (orderNumber, pickupCode, state, changedDate, extraInfo) => {
			_log('order with order number: ' + orderNumber + ' and pickup code: ' + pickupCode + ' changed to: ' + state + " at: " + changedDate);
			if(extraInfo != null && extraInfo.length > 0) _log('extra info: ' + extraInfo);
		});
				
		var start = function() {
			connection.start().then(() => { _log("SignalR Connected."); })
					  .catch((err) => { _log("Connect err: " + err); });				
		}

		connection.onclose((E) => _log('connection closed.<br/>(err: ' + E + ')') );
		connection.onreconnecting(() =>  _log('reconnecting... ') );
		connection.onreconnected(() => _log('reconnected'));

		start();

	});

});