const readline = require('readline').createInterface({
  input: process.stdin,
  output: process.stdout
});

signalR = require('@microsoft/signalr');

const yargs = require('yargs');

const options = yargs
     .usage("Usage: -u <url> -k <apikey>")
     .option("u", { alias: "url", describe: "Url to the api host (e.g.: https://api.pickup.bd.com)", type: "string", demandOption: true })
     .option("k", { alias: "apikey", describe: "The api key you were provided", type: "string", demandOption: true })
     .argv;


const connection = new signalR.HubConnectionBuilder()
    .withUrl(`${options.url}/rt-api/orderstate`, {
          accessTokenFactory: () => `apikey-${options.apikey}`,
          transport: signalR.HttpTransportType.WebSockets
        })    
    .configureLogging(signalR.LogLevel.Information)
    .build();

connection.on('OrderStateChanged', (orderNumber, pickupCode, state, changedDate, extraInfo) => {
    console.log('order with order number: ' + orderNumber + ' and pickup code: ' + pickupCode + ' changed to: ' + state + " at: " + changedDate);
    if(extraInfo != null && extraInfo.length > 0) console.log('extra info: ' + extraInfo);
});

async function start() {
    try {
        await connection.start();
        console.log("SignalR Connected.");

	readline.question('press enter to quit...', _ => {
		process.exit(0);
	});

    } catch (err) {
        console.log(err);
        setTimeout(start, 5000);
    }
};

connection.onclose(async () => {
    await start();
});

// Start the connection.
start();

